@@ -29,5 +29,12 @@ class TestModels(unittest.TestCase):
             model_name = f.replace(".prior", "")
             prior = self.get_prior(file=f)
             function = redback_surrogates.model_library.all_models_dict[model_name]
-            spectra = function(times, **prior.sample())
-            self.assertEqual((len(spectra.time), len(spectra.lambdas)), np.shape(spectra.spectra))
+            if model_name in ['typeII']:
+                print("Skipping {} model test, as it requires extra files".format(model_name))
+                pass
+            if model_name == 'tophat_emulator':
+                flux_density =  function(times, **prior.sample())
+                self.assertEqual(len(times), len(flux_density), flux_density.shape)
+            elif model_name in ['bulla_bns_kilonovanet_spectra', 'bulla_nsbh_kilonovanet_spectra', 'kasen_bns_kilonovanet_spectra']:
+                spectra = function(times, **prior.sample())
+                self.assertEqual((len(spectra.time), len(spectra.lambdas)), np.shape(spectra.spectra))
